EntryReadGuard

Struct EntryReadGuard 

pub struct EntryReadGuard<'a, K, V, const N: usize>
where K: KeyTraits,
{ /* private fields */ }
Guard for the read lock. Puts unused entries into the LRU list.

Implementations

Source

impl<K, V, const N: usize> EntryReadGuard<'_, K, V, N>
where K: KeyTraits,

pub fn expire(&mut self)

Mark the entry for expiration. When dropped it will be put in front of the LRU list and by that evicted soon. Use with care, when many entries become pushed to the front, they eventually bubble up again.