pub struct EntryWriteGuard<'a, K, V, const N: usize> where
K: KeyTraits, { /* fields omitted */ }
Guard for the write lock. Puts unused entries into the LRU list.
The resulting type after dereferencing.
Mutably dereferences the value.
Executes the destructor for this type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.